@@ -167,22 +167,6 @@ class MyWhatify:
                 print(e)
         return source_id
 
-    @classmethod
-    def preparing_data_set(cls, source_id: int, data_set_name: str, target: str = 'class',
-                           problem_type: ProblemType = ProblemType.CLASSIFICATION, header: bool = True,
-                           na_values = None, retype_columns = None, rename_columns = None, datetime_format: str = None,
-                           time_axis: str = None, block_id = None, sample_id = None, subdataset_id = None,
-                           sample_weight = None, not_used = None, wait: bool = True,
-                           skip_if_exists: bool = True):
-        dataset_id = cls.create_data_set(source_id=source_id, data_set_name=data_set_name, problem_type=problem_type,
-                                         target=target, not_used=not_used, na_values=na_values,
-                                         retype_columns=retype_columns, rename_columns=rename_columns,
-                                         sample_id=sample_id, datetime_format=datetime_format, time_axis=time_axis,
-                                         block_id=block_id, subdataset_id=subdataset_id, sample_weight=sample_weight,
-                                         header=header, skip_if_exists=skip_if_exists, wait=wait)
-
-        return dataset_id
-
     @classmethod
     def create_data_set(cls, source_id, data_set_name, problem_type=ProblemType.CLASSIFICATION, target='class',
                         not_used=None, na_values=None, retype_columns=None, rename_columns=None, sample_id=None,
@@ -209,7 +193,8 @@ class MyWhatify:
 
     @classmethod
     def train_model(cls, data_name, dataset_id, target_metric=TargetMetric.RECALL_MACRO, training_time_in_minutes=6,
-                    cv_folds=3, ensemble_size=5, interpt_level=Interpt.EXPLAINABLE, wait=True):
+                    cv_folds=3, ensemble_size=5, interpt_level=Interpt.EXPLAINABLE, max_models_num=None,
+                    wait=True, skip_if_exists=True):
         with allure.step('On data_name: ' + data_name + ' ID: ' + str(dataset_id)
                          + ' training a model with target_metric: ' + str(target_metric.value)
                          + ' cv_folds: ' + str(cv_folds) + ' ensemble_size: ' + str(ensemble_size)
@@ -245,9 +230,9 @@ class MyWhatify:
                     notes='created from Automation, run minutes: ' + str(training_time_in_minutes),
                     ensemble_size=ensemble_size,
                     n_folds=cv_folds,
-                    max_models_num=None,
+                    max_models_num=max_models_num,
                     interpretability_level=interpretability_level,
-                    timeout=training_time_in_minutes * 60, wait=wait, skip_if_exists=True
+                    timeout=training_time_in_minutes * 60, wait=wait, skip_if_exists=skip_if_exists
                 )
                 task_id = task['id']
                 ret_dict = task.to_dict()
